## Summary

<!-- Brief description of what this PR does and why. -->

## Changes

<!-- List the key changes made. -->

-

## Type of Change

- [ ] Bug fix (non-breaking change that fixes an issue)
- [ ] New feature (non-breaking change that adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Refactoring (no functional changes)

## Testing

<!-- How did you test these changes? -->

- [ ] Added/updated unit tests
- [ ] Added/updated integration tests
- [ ] Tested with optional dependencies (pandas, matplotlib)

## Checklist

- [ ] My code follows the project's code style (ruff, type hints)
- [ ] I've added tests that prove my fix/feature works
- [ ] All new and existing tests pass (`make check`)
- [ ] I've updated documentation if needed
